==> apache-dubbo-extensions-1.0.3-src.zip: apache-dubbo-extensions-1.0.3-src/dubbo-cluster-extensions/dubbo-cluster-specify-address-dubbo2/src/test/java/org/apache/dubbo/rpc/cluster/specifyaddress/UserSpecifiedAddressUtilTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.dubbo.rpc.cluster.specifyaddress;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class UserSpecifiedAddressUtilTest {
    @Test
    public void test() {
        Assertions.assertNull(UserSpecifiedAddressUtil.getAddress());
        UserSpecifiedAddressUtil.setAddress(new Address("127.0.0.1", 0));
        Assertions.assertEquals(new Address("127.0.0.1", 0), UserSpecifiedAddressUtil.getAddress());
        Assertions.assertNull(UserSpecifiedAddressUtil.getAddress());
        UserSpecifiedAddressUtil.setAddress(new Address("127.0.0.1", 12345));
        Assertions.assertNotEquals(new Address("127.0.0.1", 0), UserSpecifiedAddressUtil.getAddress());
        Assertions.assertNull(UserSpecifiedAddressUtil.getAddress());
    }
}

==> apache-dubbo-extensions-3.3.1-src.zip: apache-dubbo-extensions-3.3.1-src/dubbo-cluster-extensions/dubbo-cluster-specify-address-dubbo2/src/test/java/org/apache/dubbo/rpc/cluster/specifyaddress/UserSpecifiedAddressUtilTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.dubbo.rpc.cluster.specifyaddress;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

class UserSpecifiedAddressUtilTest {
    @Test
    void test() {
        Assertions.assertNull(UserSpecifiedAddressUtil.getAddress());
        UserSpecifiedAddressUtil.setAddress(new Address("127.0.0.1", 0));
        Assertions.assertEquals(new Address("127.0.0.1", 0), UserSpecifiedAddressUtil.getAddress());
        Assertions.assertNull(UserSpecifiedAddressUtil.getAddress());
        UserSpecifiedAddressUtil.setAddress(new Address("127.0.0.1", 12345));
        Assertions.assertNotEquals(new Address("127.0.0.1", 0), UserSpecifiedAddressUtil.getAddress());
        Assertions.assertNull(UserSpecifiedAddressUtil.getAddress());
    }
}
